@@ -1,4 +1,4 @@
-/* $Id: actions.c,v 1.40 2011/02/21 18:26:17 imil Exp $ */
+/* $Id: actions.c,v 1.1.1.1 2011/03/03 14:43:09 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -38,6 +38,7 @@
 
 const char			*pkgin_cache = PKGIN_CACHE;
 static int			upgrade_type = UPGRADE_NONE;
+static uint8_t		said = 0;	
 
 int
 check_yesno(void)
@@ -77,8 +78,17 @@ pkg_download(Deptreehead *installhead)
 		snprintf(pkg, BUFSIZ,
 		    "%s/%s%s", pkgin_cache, pinstall->depname, PKG_EXT);
 
+		/* pkg_info -X -a produces pkg_summary with empty FILE_SIZE,
+		 * people could spend some time blaming on pkgin before finding
+		 * what's really going on.
+		 */
+		if (pinstall->file_size == 0)
+			printf(MSG_EMPTY_FILE_SIZE, pinstall->depname);
+
 		/* already fully downloaded */
-		if (stat(pkg, &st) == 0 && st.st_size == pinstall->file_size)
+		if (stat(pkg, &st) == 0 && 
+			st.st_size == pinstall->file_size &&
+			pinstall->file_size != 0 )
 		    	continue;
 
 		umask(DEF_UMASK);
@@ -120,23 +130,33 @@ do_pkg_remove(Deptreehead *removehead)
 
 /* send pkg_delete stderr to logfile */
 #ifdef HAVE_FREOPEN
-	(void)freopen(PKGIN_ERR_LOG, "a", stderr);
-	printf(MSG_LOGGING_TO, PKGIN_ERR_LOG);
+	if (!verbosity && !said) {
+		(void)freopen(PKGIN_ERR_LOG, "a", stderr);
+		printf(MSG_LOGGING_TO, PKGIN_ERR_LOG);
+		said = 1;
+	}
 #endif
 
 	SLIST_FOREACH(premove, removehead, next) {
 		/* file not available in the repository */
-	    	if (premove->file_size == -1)
-		    	continue;
+		if (premove->file_size == -1)
+			continue;
 
 		if (premove->depname == NULL)
 			/* SLIST corruption, badly installed package */
 			continue;
+
+		/* pkg_install cannot be deleted */
+		if (strncmp(premove->depname, PKG_INSTALL, strlen(PKG_INSTALL)) == 0) {
+			printf(MSG_NOT_REMOVING, PKG_INSTALL);
+			continue;
+		}
+
 		printf(MSG_REMOVING, premove->depname);
-#ifdef DEBUG
-		printf("%s -f %s\n", PKG_DELETE, premove->depname);
-#else
-		fexec(PKG_DELETE, "-f", premove->depname, NULL);
+		fprintf(stderr, "%s %s %s\n",
+			PKG_DELETE, pkgtools_flags, premove->depname);
+#ifndef DEBUG
+		fexec(PKG_DELETE, pkgtools_flags, premove->depname, NULL);
 #endif
 	}
 }
@@ -151,11 +171,15 @@ do_pkg_install(Deptreehead *installhead)
 {
 	Pkgdeptree	*pinstall;
 	char		pkgpath[BUFSIZ];
+	char		pi_tmp_flags[5]; /* tmp force flags for pkg_install */
 
 /* send pkg_add stderr to logfile */
 #ifdef HAVE_FREOPEN
-	(void)freopen(PKGIN_ERR_LOG, "a", stderr);
-	printf(MSG_LOGGING_TO, PKGIN_ERR_LOG);
+	if (!verbosity && !said) {
+		(void)freopen(PKGIN_ERR_LOG, "a", stderr);
+		printf(MSG_LOGGING_TO, PKGIN_ERR_LOG);
+		said = 1;
+	}
 #endif
 
 	printf(MSG_INSTALL_PKG);
@@ -163,18 +187,36 @@ do_pkg_install(Deptreehead *installhead)
 	SLIST_FOREACH(pinstall, installhead, next) {
 
 		/* file not available in the repository */
-	    	if (pinstall->file_size == -1)
-		    	continue;
+		if (pinstall->file_size == -1)
+			continue;
 
 		printf(MSG_INSTALLING, pinstall->depname);
 		snprintf(pkgpath, BUFSIZ,
 			"%s/%s%s", pkgin_cache, pinstall->depname, PKG_EXT);
 
-#ifdef DEBUG
-		printf("%s -f %s\n", PKG_ADD, pkgpath);
-#else
-		fexec(PKG_ADD, "-f", pkgpath, NULL);
+		/* are we upgrading pkg_install ? */
+		if (strncmp(pinstall->depname, PKG_INSTALL,
+				strlen(PKG_INSTALL)) == 0) {
+			printf(MSG_UPGRADE_PKG_INSTALL, PKG_INSTALL);
+			/* set temporary force flags */
+			strncpy(pi_tmp_flags, "-ffu", 5);
+			if (verbosity)
+				/* append verbosity if requested */
+				strncat(pi_tmp_flags, "v", 2);
+			if (check_yesno()) {
+				fprintf(stderr, "%s %s %s\n", PKG_ADD, pi_tmp_flags, pkgpath);
+#ifndef DEBUG
+				fexec(PKG_ADD, pi_tmp_flags, pkgpath, NULL);
 #endif
+			} else
+				continue;
+		} else {
+			/* every other package */
+			fprintf(stderr, "%s %s %s\n", PKG_ADD, pkgtools_flags, pkgpath);
+#ifndef DEBUG
+			fexec(PKG_ADD, pkgtools_flags, pkgpath, NULL);
+#endif
+		}
 	} /* installation loop */
 }
 
@@ -404,6 +446,7 @@ pkgin_install(char **pkgargs, uint8_t do_inst)
 		/* if package is not already downloaded or size mismatch, d/l it */
 		if (stat(pkgpath, &st) < 0 || st.st_size != pimpact->file_size)
 			file_size += pimpact->file_size;
+
 		size_pkg += pimpact->size_pkg;
 
 		switch (pimpact->action) {
