@@ -1,4 +1,4 @@
-/* $Id: download.c,v 1.20 2011/01/30 10:28:09 imil Exp $ */
+/* $Id: download.c,v 1.1.1.1 2011/03/03 14:43:12 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -85,7 +85,8 @@ download_file(char *url, time_t *db_mtime)
 		p = (char *)url; /* should not happen */
 
 #ifndef _MINIX /* XXX: SSIZE_MAX fails under MINIX */
-	if (st.size > SSIZE_MAX - 1)
+	/* st.size is an off_t, it will be > SSIZE_MAX on 32 bits systems */
+	if (sizeof(st.size) == sizeof(SSIZE_MAX) && st.size > SSIZE_MAX - 1)
 		err(EXIT_FAILURE, "file is too large");
 #endif
 
