@@ -1,4 +1,4 @@
-/* $Id: fsops.c,v 1.12 2011/02/07 20:27:56 imil Exp $ */
+/* $Id: fsops.c,v 1.1.1.1 2011/03/03 14:43:12 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -47,17 +47,10 @@ int
 fs_has_room(const char *dir, int64_t size)
 {
 	int64_t				freesize;
-#ifdef HAVE_STATVFS64
-	struct statvfs64	fsbuf;
-
-
-	if (statvfs64(dir, &fsbuf) < 0)
-#else
 	struct statvfs		fsbuf;
 
 
 	if (statvfs(dir, &fsbuf) < 0)
-#endif
 		err(EXIT_FAILURE, "Can't statvfs() `%s'", dir);
 
 	freesize = (int64_t)fsbuf.f_bavail  * (int64_t)fsbuf.f_frsize;
