@@ -1,4 +1,4 @@
-/* $Id: main.c,v 1.30 2011/02/06 11:29:59 imil Exp $ */
+/* $Id: main.c,v 1.1.1.1 2011/03/03 14:43:12 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -39,9 +39,11 @@ static void	split_repos(void);
 static int	find_cmd(const char *);
 static void	missing_param(int, int, const char *);
 
-int 		yesflag = 0, noflag = 0, force_update = 0, force_reinstall = 0;
+uint8_t		yesflag = 0, noflag = 0, force_update = 0, force_reinstall = 0;
+uint8_t		verbosity = 0, package_version = 0;
 char		*env_repos, **pkg_repos;
 char		lslimit = '\0';
+char		pkgtools_flags[5];
 
 int
 main(int argc, char *argv[])
@@ -56,7 +58,7 @@ main(int argc, char *argv[])
 	if (argc < 2)
 		usage();
 
-	while ((ch = getopt(argc, argv, "dhyfFvl:nc:")) != -1) {
+	while ((ch = getopt(argc, argv, "dhyfFPvVl:nc:")) != -1) {
 		switch (ch) {
 		case 'f':
 			force_update = 1;
@@ -89,6 +91,12 @@ main(int argc, char *argv[])
 		case 'c':
 			chrootpath = optarg;
 			break;
+		case 'V':
+			verbosity = 1;
+			break;
+		case 'P':
+			package_version = 1;
+			break;
 		default:
 			usage();
 			/* NOTREACHED */
@@ -131,6 +139,12 @@ main(int argc, char *argv[])
 	/* find command index */
 	ch = find_cmd(argv[0]);
 
+	/* fill pkgtools flags */
+	if (verbosity)
+		strncpy(pkgtools_flags, "-fv", 3);
+	else
+		strncpy(pkgtools_flags, "-f", 2);
+
 	switch (ch) {
 		case PKG_UPDT_CMD:
 			update_db(REMOTE_SUMMARY, NULL);
