@@ -1,4 +1,4 @@
-/* $Id: messages.h,v 1.30 2011/02/21 18:26:17 imil Exp $ */
+/* $Id: messages.h,v 1.1.1.1 2011/03/03 14:43:12 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -41,7 +41,7 @@
 #define MSG_PKG_ARGS_UNKEEP "specify at least one package to unkeep"
 #define MSG_MISSING_SRCH "missing search string"
 
-#define MSG_USAGE "Usage: %s [-cdfFhlnvy] command [package ...]\n"
+#define MSG_USAGE "Usage: %s [-cdfFhlnPvVy] command [package ...]\n"
 #define MSG_CMDS_SHORTCUTS "\nCommands and shortcuts:\n"
 
 #define MSG_CHROOT_FAILED "Unable to chroot"
@@ -83,6 +83,9 @@
 #define MSG_EMPTY_AVAIL_PKGLIST "empty available packages list"
 #define MSG_UPGRADE_NEED_REMOVE "this upgrade needs package removal\n"
 #define MSG_LOGGING_TO "error log can be found in %s\n"
+#define MSG_EMPTY_FILE_SIZE "warning: package %s has an empty FILE_SIZE on repository.\n"
+#define MSG_NOT_REMOVING "not removing %s...\n"
+#define MSG_UPGRADE_PKG_INSTALL "about to upgrade %s, "
 
 /* depends.c */
 #define MSG_DIRECT_DEPS_FOR "direct dependencies for %s\n"
