@@ -1,4 +1,4 @@
-/* $Id: pkgin.h,v 1.32 2011/02/09 13:06:17 imil Exp $ */
+/* $Id: pkgin.h,v 1.1.1.1 2011/03/03 14:43:12 imilh Exp $ */
 
 /*
  * Copyright (c) 2009, 2010 The NetBSD Foundation, Inc.
@@ -59,6 +59,7 @@
 #define PKG_EXT ".tgz"
 #define PKGIN_CONF PKG_SYSCONFDIR"/pkgin"
 #define REPOS_FILE "repositories.conf"
+#define PKG_INSTALL "pkg_install"
 
 #define LOCAL_SUMMARY 0
 #define REMOTE_SUMMARY 1
@@ -141,13 +142,16 @@ typedef SLIST_HEAD(, Pkgdeptree) Deptreehead;
 typedef SLIST_HEAD(, Pkglist) Plisthead;
 typedef SLIST_HEAD(, Pkgimpact) Impacthead;
 
-extern int			yesflag;
-extern int			noflag;
-extern int			force_update;
-extern int			force_reinstall;
+extern uint8_t 		yesflag;
+extern uint8_t 		noflag;
+extern uint8_t 		force_update;
+extern uint8_t 		force_reinstall;
+extern uint8_t		verbosity;
+extern uint8_t		package_version;
 extern char			**pkg_repos;
 extern const char	*pkgin_cache;
 extern char  		lslimit;
+extern char			pkgtools_flags[];
 
 /* download.c*/
 Dlfile		*download_file(char *, time_t *);
